
unit AutoRefresh;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls;

type
  TAutoRefreshForm = class(TForm)
    Button1: TButton;
    GroupBox1: TGroupBox;
    ScreenTimeEdit: TEdit;
    Label3: TLabel;
    Label4: TLabel;
    ChannelTimeEdit: TEdit;
    Label5: TLabel;
    Label6: TLabel;
    RadioButton1: TRadioButton;
    RadioButton2: TRadioButton;
    RadioButton3: TRadioButton;
    procedure FormCreate(Sender: TObject);
    procedure RadioButtonClick(Sender: TObject);
    procedure CloseButtonClick(Sender: TObject);
    procedure ScreenTimeEditKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ScreenTimeEditChange(Sender: TObject);
    procedure ChannelTimeEditKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ChannelTimeEditChange(Sender: TObject);
    procedure MyKeyPress(Sender: TObject; var Key: Char);
    procedure FormDestroy(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  AutoRefreshForm: TAutoRefreshForm;

implementation

uses LockInMain;

{$R *.dfm}

procedure TAutoRefreshForm.FormCreate(Sender: TObject);
{
*Disables MainForm and timer
*Reads parameters from ini-file
*Enables section of choice
}
var
  i : Integer;
  s : String;
begin
  Top:=LockInIni.ReadInteger('GUI','AutoRefTop',20);
  if Top>Screen.DesktopHeight then Top:=Screen.DesktopHeight-20;
  Left:=LockInIni.ReadInteger('GUI','AutoRefLeft',20);
  if Left>Screen.DesktopWidth then Left:=Screen.DesktopWidth-20;

  i:=LockInIni.ReadInteger('GUI','RefreshRate',750);
  ScreenTimeEdit.Text:=IntToStr(i);

  i:=LockInIni.ReadInteger('GUI','RefreshRateChannel',200);
  ChannelTimeEdit.Text:=IntToStr(i);

  s:=LockInIni.ReadString('GUI','AutoRefresh','Off');
  if s='Screen' then  begin
    RadioButton1.Checked:=True;
  end else if s='Channels' then  begin
    RadioButton2.Checked:=True;
  end else begin
    RadioButton3.Checked:=True;
  end;
end;

procedure TAutoRefreshForm.RadioButtonClick(Sender: TObject);
var i : integer;
begin
  //Writes refresh settings to ini-file
  //Enables/disables refresh sections on AutoRefreshForm
  if RadioButton1.Checked then  begin
    LockInIni.WriteString('GUI','AutoRefresh','Screen');
    MainForm.RefreshTimer.OnTimer:=MainForm.ScreenRefreshTimerEvent;
    try
      i:=StrToInt(ScreenTimeEdit.Text);
      MainForm.RefreshTimer.Interval:=i;
    except
      ScreenTimeEdit.Color:=clRed;
    end;
    MainForm.RefreshTimer.Enabled:=true;
  end;

  if RadioButton2.Checked then  begin
    LockInIni.WriteString('GUI','AutoRefresh','Channels');
    MainForm.RefreshTimer.OnTimer:=MainForm.ChannelRefreshTimerEvent;
    MainForm.Canvas.FillRect(Rect(50,77,50+320,77+234));
    try
      i:=StrToInt(ChannelTimeEdit.Text);
      MainForm.RefreshTimer.Interval:=i;
    except
      ChannelTimeEdit.Color:=clRed;
    end;

    MainForm.RefreshTimer.Enabled:=true;
  end;

  if RadioButton3.Checked then  begin
    LockInIni.WriteString('GUI','AutoRefresh','Off');
    MainForm.RefreshTimer.Enabled:=false;
  end;
end;

procedure TAutoRefreshForm.CloseButtonClick(Sender: TObject);
// Hide AutoRefreshForm
begin
  Close;
end;

procedure TAutoRefreshForm.ScreenTimeEditKeyDown(Sender: TObject;
  var Key: Word; Shift: TShiftState);
var i : integer;
begin
  with Sender as TEdit do begin
    Color:=clSilver;
    if Key=13 then begin
      try
        i:=StrToInt(Text);
        Color:=clWhite;
        if RadioButton1.Checked then
          MainForm.RefreshTimer.Interval:=i;
        LockInIni.WriteString('GUI','RefreshRate',ScreenTimeEdit.Text);
      except
        Color:=clRed;
      end;
    end;
  end;
end;

procedure TAutoRefreshForm.ScreenTimeEditChange(Sender: TObject);
var i : integer;
begin
  try
    i:=StrToInt(ScreenTimeEdit.Text);
    ScreenTimeEdit.Color:=clWhite;
    if RadioButton1.Checked then
      MainForm.RefreshTimer.Interval:=i;
    LockInIni.WriteString('GUI','RefreshRate',ScreenTimeEdit.Text);
  except
    ScreenTimeEdit.Color:=clRed;
  end;
end;

procedure TAutoRefreshForm.ChannelTimeEditKeyDown(Sender: TObject;
  var Key: Word; Shift: TShiftState);
var i : integer;
begin
  with Sender as TEdit do begin
    Color:=clSilver;
    if Key=13 then begin
      try
        i:=StrToInt(Text);
        Color:=clWhite;
        if RadioButton2.Checked then
          MainForm.RefreshTimer.Interval:=i;
        LockInIni.WriteString('GUI','RefreshRateChannel',Text);
      except
        Color:=clRed;
      end;
    end;
  end;
end;

procedure TAutoRefreshForm.ChannelTimeEditChange(Sender: TObject);
var i : integer;
begin
  exit;
  try
    i:=StrToInt(ScreenTimeEdit.Text);
    ScreenTimeEdit.Color:=clWhite;
    if RadioButton2.Checked then
      MainForm.RefreshTimer.Interval:=i;
    LockInIni.WriteString('GUI','RefreshRateChannel',ScreenTimeEdit.Text);
  except
    ScreenTimeEdit.Color:=clRed;
  end;
end;

procedure TAutoRefreshForm.MyKeyPress(Sender: TObject;
  var Key: Char);
begin
  if key=#13 then Key:=#0;
end;

procedure TAutoRefreshForm.FormDestroy(Sender: TObject);
begin
  LockInIni.WriteInteger('GUI','AutoRefTop',Top);
  LockInIni.WriteInteger('GUI','AutoRefLeft',Left);
end;

end.
