unit SpeedTest;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls;

type
  TSpeedTestForm = class(TForm)
    TestButton: TButton;
    UpDown: TUpDown;
    Label1: TLabel;
    Label2: TLabel;
    NumEdit: TEdit;
    SizeLabel: TLabel;
    ElapsedLabel: TLabel;
    SpeedLabel: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure TestButtonClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    TimerState: Boolean;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  SpeedTestForm: TSpeedTestForm;

implementation

uses LockInMain;

{$R *.dfm}

procedure TSpeedTestForm.FormCreate(Sender: TObject);
{
*Disables MainForm
*Saves timer status
}
begin
  Top:=LockInIni.ReadInteger('GUI','SpeedTestTop',20);
  if Top>Screen.DesktopHeight then Top:=Screen.DesktopHeight-20;
  Left:=LockInIni.ReadInteger('GUI','SpeedTestLeft',20);
  if Left>Screen.DesktopWidth then Left:=Screen.DesktopWidth-20;

  MainForm.Enabled:=False;
  Visible:=True;
  with MainForm.RefreshTimer do begin
    TimerState:=Enabled;
    if Enabled=True then Enabled:=False;
  end;
end;

procedure TSpeedTestForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
{
*Re-enables timer and MainForm
}
begin
  MainForm.RefreshTimer.Enabled:=TimerState;
  MainForm.Enabled:=True;
end;

procedure TSpeedTestForm.TestButtonClick(Sender: TObject);
{
*Saves current time in ticks
*Sends 'S' to remote.cgi once to save new picture
*Retrieves picture n times
*Sums up total size
*Computes speed and time per picture
}
var
  i,n, len: Integer;
  ticks: Cardinal;
  OldCursor : TCursor;
begin
  Enabled:=False;
  TestButton.Enabled:=False;
  OldCursor:=Screen.Cursor;
  Screen.Cursor:=crHourGlass;

  ticks:=GetTickCount();
  n:=StrToInt(NumEdit.Text);
  len:=0;

  if MainForm.SendKey(ord('S'))=True then    // Send 'S' to eLockin means Save Screen
  begin
    for i:=1 to n do begin
      with MainForm do begin
        MainForm.HandleConnection('/screen.jpg');
        if Pos('no_authentication',GlobalVar.LIResponse)>0 then begin
          ShowMessage('Not logged in!');
          Break;
        end;
        len:=len+Length(GlobalVar.LIResponse);
      end;
    end; // of for
    ticks:=(GetTickCount()-ticks);
    SizeLabel.Caption:='Size: '+IntToStr(len);
    ElapsedLabel.Caption:='Time/Picture: '
                         +FloatToStrF(ticks/n/1024,ffGeneral,4,3)+' s';
    if ticks>0 then SpeedLabel.Caption:='Speed: '+FloatToStrF(len/ticks,ffGeneral,6,3)+' kB/s';
  end;

  Enabled:=True;
  TestButton.Enabled:=True;
  Screen.Cursor:=OldCursor;

end;

procedure TSpeedTestForm.FormDestroy(Sender: TObject);
begin
  LockInIni.WriteInteger('GUI','SpeedTestTop',Top);
  LockInIni.WriteInteger('GUI','SpeedTestLeft',Left);
end;

end.
